==> wamblee-support-general-0.2.1-sources.jar: org/wamblee/cache/ZeroCache.java <==
/*
 * Copyright 2005 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */ 

package org.wamblee.cache;

import java.io.Serializable;

/**
 * A cache that does not cache. This implementation is useful for disabling caching. 
 * Because of this implementation, application code does not need to distinguish 
 * between the situation where it a cache is used and where it isn't. 
 *
 * @author Erik Brakkee
 */
public class ZeroCache<KeyType extends Serializable, ValueType extends Serializable> 
   implements Cache<KeyType, ValueType> {

    public ZeroCache() { 
        // Empty. 
    }
    
    /* (non-Javadoc)
     * @see org.wamblee.cache.Cache#put(KeyType, ValueType)
     */
    public void put(KeyType aKey, ValueType aValue) {
        // Empty.    
    }
    
    /* (non-Javadoc)
     * @see org.wamblee.cache.Cache#get(KeyType)
     */
    public ValueType get(KeyType aKey) {
        return null;
    }
    
    /* (non-Javadoc)
     * @see org.wamblee.cache.Cache#remove(KeyType)
     */
    public void remove(KeyType aKey) {
        // Empty   
    }
    
    /* (non-Javadoc)
     * @see org.wamblee.cache.Cache#clear()
     */
    public void clear() {
        // Empty   
    }
}

==> wamblee-support-general-0.4.1-sources.jar: org/wamblee/cache/ZeroCache.java <==
/*
 * Copyright 2005-2010 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */ 
package org.wamblee.cache;

import java.io.Serializable;

/**
 * A cache that does not cache. This implementation is useful for disabling
 * caching. Because of this implementation, application code does not need to
 * distinguish between the situation where it a cache is used and where it
 * isn't.
 * 
 * @author Erik Brakkee
 * 
 */
public class ZeroCache<KeyType extends Serializable, ValueType extends Serializable>
    implements Cache<KeyType, ValueType> {
    /**
     * Creates a new ZeroCache object.
     */
    public ZeroCache() {
        // Empty.
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.wamblee.cache.Cache#put(KeyType, ValueType)
     */
    public void put(KeyType aKey, ValueType aValue) {
        // Empty.
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.wamblee.cache.Cache#get(KeyType)
     */
    public ValueType get(KeyType aKey) {
        return null;
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.wamblee.cache.Cache#remove(KeyType)
     */
    public void remove(KeyType aKey) {
        // Empty
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.wamblee.cache.Cache#clear()
     */
    public void clear() {
        // Empty
    }
}
